#[non_exhaustive]pub struct HP_ALIVE_SYS<'a> { /* private fields */ }unstable only.Expand description
HP_ALIVE_SYS peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl HP_ALIVE_SYS<'_>
impl HP_ALIVE_SYS<'_>
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely creates an instance of this peripheral out of thin air.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub fn reborrow(&mut self) -> HP_ALIVE_SYS<'_>
pub fn reborrow(&mut self) -> HP_ALIVE_SYS<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method to keep working with the peripheral after the driver that consumes it is dropped.
Sourceimpl HP_ALIVE_SYS<'_>
impl HP_ALIVE_SYS<'_>
Sourcepub const PTR: *const <HP_ALIVE_SYS as Deref>::Target = pac::HP_ALIVE_SYS::PTR
pub const PTR: *const <HP_ALIVE_SYS as Deref>::Target = pac::HP_ALIVE_SYS::PTR
Pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub const fn ptr() -> *const <HP_ALIVE_SYS as Deref>::Target
pub const fn ptr() -> *const <HP_ALIVE_SYS as Deref>::Target
Return the pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn regs<'a>() -> &'a <HP_ALIVE_SYS as Deref>::Target
pub fn regs<'a>() -> &'a <HP_ALIVE_SYS as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn register_block(&self) -> &<HP_ALIVE_SYS as Deref>::Target
pub fn register_block(&self) -> &<HP_ALIVE_SYS as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.